/*
 * Copyright (C) 2022 Camden Dixie O'Brien
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this program.  If not, see
 * <https://www.gnu.org/licenses/>.
 */

#include <signal.h>
#include <stdbool.h>
#include <stdio.h>
#include <unistd.h>

static bool exit_requested = false;

void handle_exit_signal(int signum)
{
	(void)signum;
	exit_requested = true;
}

int main(int argc, char *argv[])
{
	(void)argc;
	(void)argv;

	if (signal(SIGTERM, handle_exit_signal) == SIG_ERR) {
		fprintf(stderr, "Failed to register SIGTERM signal handler\n");
		return 1;
	}
	if (signal(SIGINT, handle_exit_signal) == SIG_ERR) {
		fprintf(stderr, "Failed to register SIGINT signal handler\n");
		return 1;
	}

	while (!exit_requested) {
		sleep(1);
	}

	printf("After loop\n");

	return 0;
}
